@@ -11,9 +11,18 @@ from ._conv import to_skbio_treenode, from_skbio_treenode, to_skbio_treearray
 from ._insert import insert_fully_resolved
 
 
+def load(fp, as_treenode=False):
+    data = open(fp).read()
+    tree = parse_newick(data)
+    if as_treenode:
+        return to_skbio_treenode(tree)
+    else:
+        return tree
+
+
 __all__ = ['BP', 'parse_newick', 'to_skbio_treenode', 'from_skbio_treenode',
            'to_skbio_treearray', 'write_newick', 'parse_jplace',
-           'insert_fully_resolved']
+           'insert_fully_resolved', 'load']
 
 from . import _version
 __version__ = _version.get_versions()['version']
